@@ -1382,7 +1382,7 @@ class VariableClBuilderCompress(IsoTypeHelper, Variable):
                 else:
                     yield compress
 
-        weight = {'xz': 2, 'gzip': 1}
+        weight = {'zstd': 3, 'xz': 2, 'gzip': 1}
 
         ret = list(sorted(generator(),
                           key=lambda x: (-weight.get(x, 0), x)))
